@@ -189,6 +189,8 @@ function sitemenu_projects()
 {
   global $HTML;
   $HTML->menuhtml_top(_("Hosted Projects"));
+  $HTML->menu_entry($GLOBALS['sys_home'].'register/requirements.php',
+                    _("Hosting requirements"));
   $HTML->menu_entry($GLOBALS['sys_home'].'register/',
                     _("Register New Project"),
                     1,
@@ -483,7 +485,7 @@ _("Superuser rights are required to perform site admin tasks"));
         . $GLOBALS['sys_home'] . 'account/impersonate.php' . '">'
         . '<label for="user_name">'._("Become this user:")."</label><br/>\n";
       print '<input type="hidden" name="uri" value="'
-        . $_SERVER['REQUEST_URI'] . '" />';
+        . urlencode($_SERVER['REQUEST_URI']) . '" />';
       print '<input type="text" id="user_name" name="user_name" size=10 />&nbsp;';
       print '<input type="submit" name="impersonate" value="'._("Impersonate").'" />';
       print "</form>\n";
