@@ -6,7 +6,7 @@
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
 # Copyright (C) 2007  Sylvain Beucler
-# Copyright (C) 2014, 2017-2019  Ineiev
+# Copyright (C) 2014, 2017-2021  Ineiev
 #
 # This file is part of Savane.
 #
@@ -103,13 +103,12 @@ unset($url_params['group_id']);
 # by trackers_extract_field_list.
 unset($url_params['history_date']);
 
-# ==================================================
 #   Make sure all URL arguments are captured as array. For simple
 #   search they'll be arrays with only one element at index 0 (this
 #   will avoid to deal with scalar in simple search and array in
 #   advanced which would greatly complexifies the code).
-# ================================================== */
-while (list($field,$value_id) = each($url_params))
+
+foreach ($url_params as $field => $value_id)
   {
     if (!is_array($value_id))
       {
@@ -131,7 +130,7 @@ while (list($field,$value_id) = each($url_params))
             $in = sane_import('post', array($field_op));
             $url_params[$field_op] = $in[$field_op];
             if (!$url_params[$field_op])
-              $url_params[$field_op] = '=';
+              $url_params[$field_op] = array ('=');
           }
       }
   }
@@ -187,11 +186,9 @@ if ($morder != '')
                             $morder);
   }
 
-# ==================================================
 #  If the report type is not defined then get it from the user preferences.
 #  If it is set then update the user preference.  Also initialize the
 #  bug report structures.
-#  ==================================================
 if (user_isloggedin())
   {
     if (!isset($report_id))
@@ -203,6 +200,10 @@ if (user_isloggedin())
                           $report_id);
   }
 
+# If the report type is not defined then get it from group preferences.
+if (!$report_id)
+  $report_id = group_get_preference ($group_id, ARTIFACT . "_default_query");
+
 # If still not defined then force it to system 'Basic' report
 # of to 'Sober Basic' in sober mode, 103. This is hardcoded, if at some point
 # we need to put the sober output of existing trackers where 103 may already
@@ -223,7 +224,6 @@ if (!trackers_report_init($report_id))
     trackers_report_init ($report_id);
   }
 
-# ==================================================
 #  Now see what type of bug set is requested (set is one of none,
 #  'my', 'open', 'custom').
 #    - if no set is passed in, see if a preference was set ('custom' set).
@@ -231,7 +231,6 @@ if (!trackers_report_init($report_id))
 #    - if no preference and not logged in the use 'open' set
 #     (Prefs is a string of the form
 #     &amp;field1[]=value_id1&amp;field2[]=value_id2&amp;.... )
-#  ==================================================
 if (!$set)
   {
     if (!user_isloggedin())
@@ -245,7 +244,8 @@ if (!$set)
         else
           {
             $pref_arr = explode('&amp;', substr($custom_pref, 5));
-            while (list(,$expr) = each($pref_arr))
+
+            foreach ($pref_arr as $expr)
               {
                 # Extract left and right parts of the assignment
                 # and remove the '[]' array symbol from the left part.
@@ -272,9 +272,9 @@ if (!$set)
                     $history_event = $hist_pref[2];
                     $history_date = $hist_pref[3];
 
-                    # if not args in url (means not after post) ...
+                    # If not args in URL (means not after post) ...
                     # set $url_params['history'] explicitly since 'history'
-                    # is not a tracker field and thus wont have been set.
+                    # is not a tracker field and thus won't be set.
                     $url_params['history'][] = $history_search.'>'
                       .$history_field.'>'.$history_event.'>'.$history_date;
                   }
@@ -300,29 +300,36 @@ else if ($set=='custom')
   #     return date arguments (using _dayfd|monthfd|yearfd boxes) whether
   #     or not they were tracker fields used by the project.
 
-    reset($url_params);
     $pref_stg = '';
-    while (list($field,$arr_val) = each($url_params))
+    foreach ($url_params as $field => $arr_val)
       {
-        while (list(,$value_id) = each($arr_val))
-          $pref_stg .= '&amp;'.$field.'[]=' . $value_id;
+        foreach ($arr_val as $value_id)
+          $pref_stg .= '&amp;' . $field . '[]=' . $value_id;
 
-      # build part of the HTML title of this page for more friendly bookmarking.
+      # Build part of the HTML title of this page for more friendly bookmarking.
       # Do not add the criteria in the header if value is "Any".
         if ($value_id != 0)
           {
+            $field_value = $value_id;
+            if (trackers_data_is_date_field ($field))
+              {
+                list ($field_value, $ok) = utils_date_to_unixtime ($value_id);
+                if (!$ok)
+                  $field_value = $value_id;
+              }
+            $hdr = sprintf(
 # TRANSLATORS: the argument is field name.
-            $hdr = sprintf(_("Browse Items By %s: "),
+                           _("Browse Items By %s: "),
                             trackers_data_get_label($field))
-               .trackers_data_get_value($field,$group_id,$value_id);
+               . trackers_data_get_value ($field, $group_id, $field_value);
           }
       }
-    $pref_stg .= '&amp;advsrch='.$advsrch;
-    $pref_stg .= '&amp;msort='.$msort;
-    $pref_stg .= '&amp;chunksz='.$chunksz;
-    $pref_stg .= '&amp;spamscore='.$spamscore;
-    $pref_stg .= '&amp;report_id='.$report_id;
-    $pref_stg .= '&amp;sumORdet='.$sumORdet;
+    $pref_stg .= '&amp;advsrch=' . htmlspecialchars ($advsrch);
+    $pref_stg .= '&amp;msort=' . htmlspecialchars ($msort);
+    $pref_stg .= '&amp;chunksz=' . htmlspecialchars ($chunksz);
+    $pref_stg .= '&amp;spamscore=' . htmlspecialchars ($spamscore);
+    $pref_stg .= '&amp;report_id=' . htmlspecialchars ($report_id);
+    $pref_stg .= '&amp;sumORdet=' . htmlspecialchars ($sumORdet);
 
     if ($pref_stg != user_get_preference($preference_prefix.'_brow_cust'
                                          .$group_id))
@@ -441,7 +448,7 @@ reset($url_params);
 $summary_search = 0;
 $details_search = 0;
 
-while (list($field,$value_id) = each($url_params))
+foreach ($url_params as $field => $value_id)
   {
   # If the criteria is not in the field showed on query screen then
   # skip it. This is a sanity check to make sure that the SQL
@@ -625,17 +632,30 @@ while ($field = trackers_list_all_fields('cmp_place_query'))
       }
     elseif (trackers_data_is_date_field($field))
       {
+        $end_value = '';
+        if (isset ($url_params[$field . '_end'])
+            && isset ($url_params[$field . '_end'][0]))
+          $end_value = $url_params[$field . '_end'][0];
+
+        $op_value = '';
+        if (isset ($url_params[$field . '_op'])
+            && isset ($url_params[$field . '_op'][0]))
+          $op_value = $url_params[$field . '_op'][0];
+
+        $value = '';
+        if (isset ($url_params[$field])
+            && isset($url_params[$field][0]))
+          $value = $url_params[$field][0];
+
         if ($advsrch)
           {
-            $boxes .= trackers_multiple_field_date($field,$url_params[$field][0],
-                                                   $url_params[$field.'_end'][0],
-                                                   0,0,$printer);
+            $boxes .= trackers_multiple_field_date ($field, $value, $end_value,
+                                                    0, 0, $printer);
           }
         else
           {
-            $boxes .= trackers_field_date_operator($field,
-              $url_params[$field.'_op'][0],$printer)
-              .trackers_field_date($field,$url_params[$field][0],0,0,$printer);
+            $boxes .= trackers_field_date_operator($field, $op_value, $printer)
+              . trackers_field_date($field, $value, 0, 0, $printer);
           }
       }
     elseif (trackers_data_is_text_field($field)
@@ -760,10 +780,10 @@ while ($field = trackers_list_all_fields('cmp_place_result'))
       # Less simple in multicolumn, indeed.
         $morder_icon_is_set = 0;
         $morder_arr = explode(',',$morder);
-        while (list(,$crit) = each($morder_arr))
+
+        foreach ($morder_arr as $crit)
           {
-            if ($crit == "$field<"
-                || $crit == "$field>")
+            if ($crit == "$field<" || $crit == "$field>")
               {
                 $so = trackers_sorting_order ($morder);
                 $lbl_list[] = trackers_data_get_label($field).' '
@@ -898,7 +918,7 @@ while ($thisarray = db_fetch_array($result))
 $form_submit = '';
 if ($printer)
   trackers_header(array('title'=>_("Browse Items").' - '
-                                 .utils_format_date(time())));
+                                 . utils_format_date(time())));
 else
   trackers_header(array('title'=>$hdr));
 
@@ -1094,7 +1114,7 @@ while ($field = trackers_list_all_fields())
 # Order them by name: in a select box, following the configure output order
 # is not user-friendly.
 asort($fextracted);
-while (list($field,$label) = each($fextracted))
+foreach ($fextracted as $field => $label)
   {
     $fname[] = $field;
     $flabel[] = $label;
