@@ -167,7 +167,7 @@ switch ($func)
                           'details' => $fields['details']));
      $stat_id = db_insertid (NULL);
 
- if (!user_isloggedin() && ($_POST['check'] != 1984))
+ if (!user_isloggedin() && !(isset($_POST['check']) && $_POST['check'] == 1984))
    exit_error(_("You're not logged in and you didn't enter the magic
 anti-spam number, please go back!"));
 
@@ -187,7 +187,7 @@ anti-spam number, please go back!"));
        {
          # Attach new file if there is one.
          # As we need to create the item first to have an item id so this
-         # function can work properly, we wont be able to update the
+         # function can work properly, we shan't be able to update the
          # comment on-the-fly to mention in the comment the attached files.
          # However, this is unlikely to be a problem because the attached
          # files is the section next to comments, and the original
