@@ -6,7 +6,7 @@
 # Copyright (C) 2002-2006 Tobias Toedter <t.toedter--gmx.net>
 # Copyright (C) 2004-2007 Aidan Lister <aidan@php.net>, Arpad Ray <arpad@php.net>
 # Copyright (C) 2006, 2007, 2008, 2010 Sylvain Beucler
-# Copyright (C) 2017, 2018, 2019 Ineiev
+# Copyright (C) 2017, 2018, 2019, 2020 Ineiev
 #
 # This file is part of Savane.
 #
@@ -205,7 +205,7 @@ function utils_email_basic ($address, $nohtml=0)
 # Find out if a string is pure ASCII or not.
 function utils_is_ascii ($string)
 {
-  return preg_match('%^(?: [\x09\x0A\x0D\x20-\x7E] )*$%xs', $string);
+  return preg_match('%^[[:ascii:]]*$%', $string);
 }
 
 # Alias function.
@@ -657,25 +657,20 @@ function utils_user_link ($username, $realname=false, $noneisanonymous=false)
 function utils_double_diff_array($arr1, $arr2)
 {
   # First transform both arrays in hashes.
-  reset($arr1); reset($arr2);
-  while ( list(,$v) = each($arr1))
+  foreach ($arr1 as $v)
     $h2[$v] = $v;
-  while ( list(,$v) = each($arr2))
+  foreach ($arr2 as $v)
     $h2[$v] = $v;
 
   $deleted = array();
-  while ( list($k,) = each($h2))
-    {
-      if (!isset($h2[$k]))
-        $deleted[] = $k;
-    }
+  foreach ($h2 as $k => $v)
+    if (!isset($h2[$k]))
+      $deleted[] = $k;
 
   $added = array();
-  while ( list($k,) = each($h2))
-    {
-      if (!isset($h2[$k]))
-        $added[] = $k;
-    }
+  foreach ($h2 as $k => $v)
+    if (!isset($h2[$k]))
+      $added[] = $k;
   return array($deleted, $added);
 }
 
@@ -897,11 +892,10 @@ function validate_email ($address)
 function validate_emails ($addresses)
 {
   $arr = utils_split_emails($addresses);
-  while (list(, $addr) = each ($arr))
-    {
-      if (!validate_email($addr))
-        return false;
-    }
+
+  foreach ($arr as $addr)
+    if (!validate_email($addr))
+      return false;
   return true;
 }
 
@@ -1105,20 +1099,18 @@ function help ($text, $explanation_array, $noarray=0)
 {
   if (!$noarray)
     {
-      while (list($word,$explanation) = each($explanation_array))
-        {
-          $text = str_replace($word,
-                              '<span class="help" title="'.$explanation.'">'
-                              .$word.'</span>',
-                              $text);
-        }
+      foreach ($explanation_array as $word => $explanation)
+        $text = str_replace($word,
+                            '<span class="help" title="' . $explanation . '">'
+                            . $word . '</span>',
+                            $text);
       return $text;
     }
   return '<span class="help" title="'.$explanation_array.'">'.$text.'</span>';
 }
 
 # Analyse if we do need MSIE dirtyhacks.
-# Put the result in cache so we wont over and over analyse user agent.
+# Put the result in cache so we shan't over and over analyse user agent.
 # (This function will indeed think a browser that claims to be MSIE that it is
 # MSIE. Users of browsers like Opera that pretend to be MSIE should configure
 # properly their User Agent. There is nothing else to do about it).
@@ -1165,4 +1157,22 @@ function utils_setcookie ($name, $value, $expire, $secure = false)
   setcookie($name, $value, $expire, $GLOBALS['sys_home'], '',
             $secure, true);
 }
+
+function utils_set_csp_headers ()
+{
+  if (empty ($GLOBALS['skip_csp_headers']))
+    return;
+  # Set up proper use of UTF-8, even if the webserver doesn't serve it by default.
+  header('Content-Type: text/html; charset=utf-8');
+  # Disallow embedding in any frames.
+  header('X-Frame-Options: DENY');
+  # Declare more restrictions on how browsers may assemble pages.
+  # Security issues apply even during fundrasing periods.  Please don't disable
+  # this; instead, add some domain to img-src (or (better?) copy necessary
+  # images to images/ or to submissions_uploads/).
+  $policy = "Content-Security-Policy: default-src 'self'; frame-ancestors 'none'";
+  if ($GLOBALS['sys_file_domain'] != $GLOBALS['sys_default_domain'])
+    $policy .= "; img-src 'self' " . $GLOBALS['sys_file_domain'];
+  header($policy);
+}
 ?>
