@@ -4,9 +4,9 @@
 # Copyright (C) 1999-2000 The SourceForge Crew
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2007, 2013  Sylvain Beucler
+# Copyright (C) 2007, 2013 Sylvain Beucler
 # Copyright (C) 2016 Karl Berry
-# Copyright (C) 2017, 2018 Ineiev
+# Copyright (C) 2017, 2018, 2020, 2021 Ineiev
 #
 # This file is part of Savane.
 #
@@ -23,14 +23,15 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
 require_once('../../include/init.php');
 require_once('../../include/sendmail.php');
-register_globals_off();
-# should be mysql-safe, needs various input validation + !!tests!!
+require_once('../../include/gpg.php');
 
-########################################################################
-# Preliminary checks
+require(utils_get_content_filename ("gpg-sample"));
+register_globals_off();
+# Should be mysql-safe, needs various input validation + !!tests!!
+
+# Preliminary checks.
 # Check if the user is logged in.
 session_require(array('isloggedin'=>'1'));
 
@@ -41,148 +42,6 @@ extract(sane_import('request',
 if (!$item)
   exit_missing_param();
 
-function test_gpg_listing ($gpg_name, $temp_dir, &$ret)
-{
-  $ret .= "<h2>"._("Listing key")."</h2>\n"
-                     ."<p>". _("Output:")."</p>";
-  $cmd = $gpg_name . " --home " . $temp_dir
-                   . " --list-keys --fingerprint ";
-  $d_spec = array (0 => array("pipe", "r"), 1 => array("pipe", "w"),
-                   2 => array("pipe", "w"));
-  $my_env = $_ENV;
-  # Let non-ASCII user IDs show up in a readable way.
-  $my_env['LC_ALL'] = "C.UTF-8";
-  $gpg_proc = proc_open ($cmd, $d_spec, $pipes, NULL, $my_env);
-  fclose ($pipes[0]);
-  $gpg_output = stream_get_contents ($pipes[1]);
-  $gpg_errors = stream_get_contents ($pipes[2]);
-  fclose ($pipes[1]); fclose ($pipes[2]);
-  $gpg_result = proc_close($gpg_proc);
-  $ret .= "<pre>\n";
-  $ret .= htmlentities($gpg_output);
-  $ret .= "</pre>\n";
-  $ret .= "<p>". _("Errors:")."</p>\n";
-  $ret .= "<pre>\n";
-  $ret .= htmlentities($gpg_errors);
-  $ret .= "</pre>\n";
-  $ret .= "<p>"._("Exit status:")." ";
-  $ret .= $gpg_result . "</p>\n";
-  return $gpg_result;
-}
-
-function test_gpg_import ($gpg_name, $key, $temp_dir, &$output)
-{
-  $output .= "<h2>"._("Importing key")."</h2>\n";
-  $cmd = $gpg_name . " --home '".$temp_dir."' --batch --import";
-  $d_spec = array (0 => array("pipe", "r"), 1 => array("pipe", "w"),
-                   2 => array("pipe", "w"));
-  $my_env = $_ENV;
-  $my_env['LC_ALL'] = "C.UTF-8";
-  $gpg_proc = proc_open ($cmd, $d_spec, $pipes, NULL, $my_env);
-  fwrite ($pipes[0], $key);
-  fclose ($pipes[0]);
-  $gpg_errors = stream_get_contents ($pipes[2]);
-  fclose ($pipes[1]); fclose ($pipes[2]);
-  $gpg_result = proc_close($gpg_proc);
-  $output .= "<pre>\n";
-  $output .= htmlentities($gpg_errors);
-  $output .= "</pre>\n";
-  $output .= "<p>"._("Exit status:")." ";
-  $output .= $gpg_result . "</p>\n";
-  return $gpg_result;
-}
-
-function test_gpg_encryption ($gpg_name, $temp_dir, &$output)
-{
-# The message is a slightly modified ASCII art
-# from https://www.gnu.org/graphics/gnu-ascii2.html .
-  $message = "
-  ,' ,-_-. '.
- ((_/)o o(\\_))
-  `-'(. .)`-'
-      \\_/\n";
-  $cmd = 'perl ../../../perl/encrypt-to-user/index.pl '
-         .'--home="'.$temp_dir.'" --gpg=' . $gpg_name;
-
-  $d_spec = array(
-      0 => array("pipe", "r"), 1 => array("pipe", "w"),
-      2 => array("pipe", "w"));
-
-  $gpg_proc = proc_open($cmd, $d_spec, $pipes, NULL, $_ENV);
-
-  fwrite($pipes[0], $message);
-  fclose($pipes[0]);
-  $encrypted_message = stream_get_contents($pipes[1]);
-  $gpg_stderr = stream_get_contents($pipes[2]);
-  fclose($pipes[1]); fclose($pipes[2]);
-  $gpg_result = proc_close($gpg_proc);
-  $gpg_error = "";
-  if($gpg_result != 0 or $encrypted_message === FALSE or $encrypted_message === "")
-    {
-      $encrypted_message = "";
-      if($gpg_result == 1)
-        $gpg_error = _("Encryption failed.");
-      else if($gpg_result == 2)
-        $gpg_error = _("No key for encryption found.");
-      else if($gpg_result == 3)
-        $gpg_error = _("Can't extract user_id from database.");
-      else if($gpg_result == 4)
-        $gpg_error = _("Can't create temporary files.");
-      else if($gpg_result == 5)
-        $gpg_error = _("Extracted GPG key ID is invalid.");
-      $encrypted_message = "";
-    }
-  $output .= "<h2>"._("Test Encryption")."</h2>\n";
-  if ($gpg_result)
-    $output .= "<p>"._("Errors:")." ".$gpg_error."</p>\n";
-  else
-    {
-      $output .= "<p>"
-._("Encryption succeeded; you should be able to decrypt this with
-<em>gpg --decrypt</em>:")."</p>\n";
-      $output .= "<pre>". $encrypted_message ."</pre>\n";
-    }
-  return $gpg_result;
-}
-
-function run_gpg_tests ($gpg_name, $key, $temp_dir, &$output)
-{
-  if (test_gpg_import ($gpg_name, $key, $temp_dir, $output))
-    return;
-  if (test_gpg_listing ($gpg_name, $temp_dir, $output))
-    return;
-  test_gpg_encryption ($gpg_name, $temp_dir, $output);
-}
-function run_gpg_checks ($key)
-{
-  $ret = "";
-  $ret .= "<h2>"._("GnuPG version")."</h2>\n";
-  $gpg_name = "'" . $GLOBALS['sys_gpg_name'] . "'";
-  $cmd = $gpg_name . ' --version';
-  $d_spec = array (0 => array("pipe", "r"), 1 => array("pipe", "w"),
-                   2 => array("file", "/dev/null", "a"));
-
-  $gpg_proc = proc_open ($cmd, $d_spec, $pipes, NULL, $_ENV);
-  fclose ($pipes[0]);
-  $gpg_output = stream_get_contents ($pipes[1]);
-  fclose ($pipes[1]);
-  proc_close($gpg_proc);
-  $ret .= "<pre>\n";
-  $ret .= htmlentities($gpg_output);
-  $ret .= "</pre>\n";
-
-  $temp_dir = exec ("mktemp -d");
-  if (is_dir ($temp_dir))
-    {
-      run_gpg_tests ($gpg_name, $key, $temp_dir, $ret);
-      system ("rm -r '". $temp_dir ."'");
-    }
-  else
-    $ret .= "<p>"._("Can't create temporary directory.")."</p>\n";
-  $ret .= "\n<hr />\n";
-  return $ret;
-}
-
 $success = FALSE;
 
 # To delete the account, the user must have first quitted all groups.
@@ -219,7 +78,7 @@ if ($update)
   # Update the database and redirect to account conf page.
     if ($item == "realname")
       {
-        if (!$newvalue)
+        if (!account_realname_valid ($newvalue))
           fb(_("You must supply a new real name."), 1);
         else
           {
@@ -371,9 +230,10 @@ _("-- the %s team."),
                     $warning_message = sprintf(
 # TRANSLATORS: the argument is site name (like Savannah).
 _('Someone, presumably you, has requested a change of email address on %s.
-If it wasn\'t you, maybe someone is trying to steal your account...')."\n\n"
-._('Your current address is %1$s, the supposedly new address is %2$s.'),
-$GLOBALS['sys_name'], $row_user['email'], $newvalue).'
+If it wasn\'t you, maybe someone is trying to steal your account...') . "\n\n",
+$GLOBALS['sys_name']) . sprintf (
+_('Your current address is %1$s, the supposedly new address is %2$s.'),
+         $row_user['email'], $newvalue) . '
 
 ' . _('If you did not request that change, please visit the following URL
 to discard the email change and report the problem to us:')
@@ -590,7 +450,6 @@ _("Unable to understand what to do, parameters are probably missing"),
                        .rawurlencode($feedback));
   } # if ($update).
 
-########################################################################
 # If we reach this point, it means that not sucessful update has been
 # already made.
 
@@ -666,61 +525,22 @@ elseif ($item == "gpgkey")
     $res_user = db_execute("SELECT gpg_key FROM user WHERE user_id=?",
                            array(user_getid()));
     $row_user = db_fetch_array($res_user);
-    $title = _("Change GPG Key");
+    $title = _("Change GPG Keys");
     $input_title = "";
-    $input_specific =
-"<h2>"._("Sample GPG key")."</h2>\n"
-.'<p>'._('The exported public GPG key should look like this:')
-.'</p>
-<pre>
------BEGIN PGP PUBLIC KEY BLOCK-----
-
-mQENBFr1PisBCAC9xQcWyOZRLa6K2g7NJbvQmm7p89/xifFYXPpMTQAnlSoCtUdZ
-oznXNR4oFYIqTasaXCFpG5uFCTDObPOSg1JqRDZYckijkAvbYlieBY6/ItrQxjyS
-b0VcBN/UNvn3BiGOIUZOuDkAM2dwR0AwCS0blKdIBZ5PMrAm0+NvuZAZzVYRXVas
-7NHflqCKWLhctDR9lg2bf7mpnjiywrV0BuLTp4xFhCue30juqfn+udZpZ+uq7QyV
-arWY3CBRTepXTLcgxpXtmRUU6KfTVMEaFZoJhemnD0PAUQ9ReWIOLVYTZbgdwp98
-wv8QaZTK+aaRMTBlDrLkMZCWlem0370WgL0XABEBAAG0I9CS0LDRgdGPINCf0YPR
-iNC60LjQvSA8dnBAdGVzdC5vcmc+iQFTBBMBCAA9FiEERHdxNm0nSYKP0OaDAjlB
-ZosL8WAFAlr1PisCGwMFCQPCZwAFCwkIBwIGFQoJCAsCAxYCAQIeAQIXgAAKCRAC
-OUFmiwvxYKMHB/9Zs2ptiMtUfh9tTpC/3k9Df8z3kIfxWI7n2Tw6YLKow9lbjgfL
-UfcZIAXHBv9RteU748J/fscmDv2i1a83vJ+JBF9GQJacENAgkoB5ChWNAeI/ifCS
-NpWl+NUv9DKkyG1GXU5icLmBJP+b5ASLtyuqnfgT2bCYlIo3PREkjLs4cfAUAtOY
-c/1FYbth2tQRCXnujRqqzz+6+qYRkTz91WFWc7/GYJ2obwsTrRrPfYQM02Dx77Lm
-9ir8GtWbC6xiOtRwDY2RyBlnYQj53XGaFljxOsqzTzUa0NLGmnBf3JXI6D+gWLK1
-vZaKd2Kp9U6cr5kNP6fUxJPI2LEMBfX1tTMquQENBFr1PisBCACuqpIVoWT9yGzH
-VRO12/hDAxROE1RzngTc7HrsuL2wfY2PDZ0hWOfJpU778TGrmtrTQT5DPBY1ECJM
-Nw1j9WRUtnxPXCE8LLNd5zEdTQm7M1P/XVxrzVyItU3AyJUYjvypTNROrbrkoVhQ
-0AMApawRG6chGLMkRxlhB7TCy/EJnlhNh+8xmsWXWQV3YLPIsfWnutvNSrIjE59q
-4qDdwOWj8GhwtPd83lSBRCA1cGAikCaXvXYJRUUvbJt2PQni9/jQL0FC6fA6OACO
-ab61aegk9JWoPbxUVUigzGTYQ1Xy00U4KLD9Eq0ivHTQTx7huNk7DjvN5PH54FdW
-I01HJSNHABEBAAGJATwEGAEIACYWIQREd3E2bSdJgo/Q5oMCOUFmiwvxYAUCWvU+
-KwIbDAUJA8JnAAAKCRACOUFmiwvxYO4yB/wKYJvIwGBclcX1OcNPmGcR2ckLZCYP
-Ixuo21RtACp2kSV2CqUsi437caV0YrdHiv4IUgT2mKmy2NP6MUhrh6r9zaUpW9kx
-Sj5RZdLZZNhiCRB8Lw/Nis9g/OHksDhKbgM3po8iIq6HC3cC1jSDjxuVQhCt5FAm
-7oCNj7Bmi1bHEZXihOyjyz8wNEVp5xqYTtRrEXIQY6hbxR7VXZb2z++jWlsF0IS3
-1rMbVMNua84/W98JMFHvu/RNNpmnHvIQoEw7yjVZYt2aTJN/uuGtugNCZ+wri+xh
-yl1VWoHhHrHs1zAWDiJSmB4k0zV9Yyw/OMMlPrmMX3SfFEjMDqnC1SNi
-=hZua
------END PGP PUBLIC KEY BLOCK-----
-</pre>
-<p>'
-._("Please don't remove begin and end markers when submitting your GPG key.")
-."</p>\n"
-.'<h2>'._("Update your key in the input area below")."</h2>\n"
-.'<p>'
-._("Insert your (ASCII) public key here (made with gpg --export --armor KEYID):")
-."</p>\n";
+    $input_specific = $gpg_sample_text;
 
     if (!$newvalue)
       $newvalue = $row_user['gpg_key'];
 
     $input_specific .= '<textarea title="'._("New GPG key")
-                      .'" cols="70" rows="10" '
+                      .'" cols="70" rows="20" '
                       .'wrap="virtual" name="newvalue">'.$newvalue
                       ."</textarea>\n";
     $input_specific .= '<p><input type="submit" name="test_gpg_key" value="'
-                       ._("Test GPG key").'" /></p>'."\n<hr />\n";
+                       ._("Test GPG keys").'" /> '
+                       ._("(Testing is recommended before updating.)").'</p>'
+                       ."\n<hr />\n";
+    $input_specific .= $gpg_gnu_maintainers_note;
     if ($test_gpg_key)
       $input_specific .= run_gpg_checks ($newvalue);
   }
@@ -792,7 +612,6 @@ elseif ($item == "delete")
 if (!$title)
   $title = sprintf (_("Unknown user settings item (%s)"), $item);
 
-########################################################################
 # Actually print the HTML page.
 site_user_header(array('title'=>$title,
                        'context'=>'account'));
