@@ -248,10 +248,9 @@ which are not attributed by default when joining this project.").'</p>
     print "\t</table>\n";
   }
 
-if ($project->getGPGKeyring())
+if (if ($project->getGPGKeyring()))
   print '<p>'
-.sprintf(_('You may also be interested in the <a href="%s">GPG Keyring of
-this project</a>'), 'memberlist-gpgkeys.php?group='.$group).'</p>
-';
+. sprintf(_('You may also be interested in the <a href="%s">GPG Keys of
+all members</a>'), 'memberlist-gpgkeys.php?group=' . $group) . "</p>\n";
 site_project_footer(array());
 ?>
